Igt-dev Archive on lore.kernel.org
 help / color / mirror / Atom feed
From: Jeevan B <jeevan.b@intel.com>
To: igt-dev@lists.freedesktop.org
Cc: petri.latvala@intel.com, jose.souza@intel.com, daniel@ffwll.ch,
	Jeevan B <jeevan.b@intel.com>
Subject: [igt-dev] [PATCH i-g-t v2 1/3] lib/igt_aux: Rename igt_debug_manual_check and assert check if all is supplied
Date: Wed, 13 Oct 2021 22:40:49 +0530	[thread overview]
Message-ID: <20211013171051.26287-2-jeevan.b@intel.com> (raw)
In-Reply-To: <20211013171051.26287-1-jeevan.b@intel.com>

rename igt_debug_manual_check and patch the igt function
igt_debug_wait_for_keypress() to assert if "all" is supplied.

v2: calling igt_debug_wait_for_keypress() with "all" will assert.

Signed-off-by: Jeevan B <jeevan.b@intel.com>
---
 lib/igt_aux.c            | 9 ++++++---
 lib/igt_aux.h            | 2 +-
 tests/i915/kms_dsc.c     | 2 +-
 tests/i915/kms_psr.c     | 2 +-
 tests/i915/kms_psr2_sf.c | 2 +-
 5 files changed, 10 insertions(+), 7 deletions(-)

diff --git a/lib/igt_aux.h b/lib/igt_aux.h
index 30b175d7..cfa68be3 100644
--- a/lib/igt_aux.h
+++ b/lib/igt_aux.h
@@ -195,7 +195,7 @@ int igt_get_autoresume_delay(enum igt_suspend_state state);
 void igt_drop_root(void);
 
 void igt_debug_wait_for_keypress(const char *var);
-void igt_debug_manual_check(const char *var, const char *expected);
+void igt_debug_interactive_mode_check(const char *var, const char *expected);
 
 /* sysinfo cross-arch wrappers from intel_os.c */
 
diff --git a/tests/i915/kms_dsc.c b/tests/i915/kms_dsc.c
index 3e450207..772687f4 100644
--- a/tests/i915/kms_dsc.c
+++ b/tests/i915/kms_dsc.c
@@ -72,7 +72,7 @@ int force_dsc_restore_fd = -1;
 
 static inline void manual(const char *expected)
 {
-	igt_debug_manual_check("all", expected);
+	igt_debug_interactive_mode_check("all", expected);
 }
 
 static void force_dsc_enable(data_t *data)
diff --git a/tests/i915/kms_psr.c b/tests/i915/kms_psr.c
index c65b3c80..e7dbf8b7 100644
--- a/tests/i915/kms_psr.c
+++ b/tests/i915/kms_psr.c
@@ -246,7 +246,7 @@ static bool psr_enable_if_enabled(data_t *data)
 
 static inline void manual(const char *expected)
 {
-	igt_debug_manual_check("all", expected);
+	igt_debug_interactive_mode_check("all", expected);
 }
 
 static bool drrs_disabled(data_t *data)
diff --git a/tests/i915/kms_psr2_sf.c b/tests/i915/kms_psr2_sf.c
index 1be8c3da..93347327 100644
--- a/tests/i915/kms_psr2_sf.c
+++ b/tests/i915/kms_psr2_sf.c
@@ -331,7 +331,7 @@ static void prepare(data_t *data)
 
 static inline void manual(const char *expected)
 {
-	igt_debug_manual_check("all", expected);
+	igt_debug_interactive_mode_check("all", expected);
 }
 
 static void plane_update_expected_output(int plane_type, int box_count)
diff --git a/lib/igt_aux.c b/lib/igt_aux.c
index 1217f5e8..78798287 100644
--- a/lib/igt_aux.c
+++ b/lib/igt_aux.c
@@ -972,7 +972,7 @@ void igt_drop_root(void)
  * Waits for a key press when run interactively and when the corresponding debug
  * var is set in the --interactive-debug=$var variable. Multiple keys
  * can be specified as a comma-separated list or alternatively "all" if a wait
  * should happen for all cases.
  *
  * When not connected to a terminal interactive_debug is ignored
  * and execution immediately continues.
@@ -993,6 +993,9 @@ void igt_debug_wait_for_keypress(const char *var)
 	if (!igt_interactive_debug)
 		return;
 
+	if (strstr(var, "all"))
+		igt_assert(false);
+
 	if (!strstr(igt_interactive_debug, var) &&
 	    !strstr(igt_interactive_debug, "all"))
 		return;
@@ -1008,7 +1011,7 @@ void igt_debug_wait_for_keypress(const char *var)
 }
 
 /**
- * igt_debug_manual_check:
+ * igt_debug_interactive_mode_check:
  * @var: var lookup to to enable this wait
  * @expected: message to be printed as expected behaviour before wait for keys Y/n
  *
@@ -1028,7 +1031,7 @@ void igt_debug_wait_for_keypress(const char *var)
  *
  * Force test fail when N/n is pressed.
  */
-void igt_debug_manual_check(const char *var, const char *expected)
+void igt_debug_interactive_mode_check(const char *var, const char *expected)
 {
 	struct termios oldt, newt;
 	char key;
@@ -972,7 +972,7 @@ void igt_drop_root(void)
  * var is set in the --interactive-debug=$var variable. Multiple keys
  * can be specified as a comma-separated list or alternatively "all" if a wait
- * should happen for all cases.
+ * should happen for all cases. Calling this fucntion with "all" will assert.
  *
  * When not connected to a terminal interactive_debug is ignored
-- 
2.19.1

  reply	other threads:[~2021-10-13 17:08 UTC|newest]

Thread overview: 8+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2021-10-13 17:10 [igt-dev] [PATCH i-g-t v2 0/3] Fix kms_psr2_sf test and add new test for FB_DAMAGE_CLIPS plane property Jeevan B
2021-10-13 17:10 ` Jeevan B [this message]
2021-11-08 14:43   ` [igt-dev] [PATCH i-g-t v2 1/3] lib/igt_aux: Rename igt_debug_manual_check and assert check if all is supplied Petri Latvala
2021-10-13 17:10 ` [igt-dev] [PATCH i-g-t v2 2/3] tests/kms_psr2_sf: Make this a generic test and change testcase design Jeevan B
2021-11-08 14:47   ` Petri Latvala
2021-10-13 17:10 ` [igt-dev] [PATCH i-g-t v2 3/3] tests/kms_atomic: Add a new test case for FB_DAMAGE_CLIPS plane property Jeevan B
2021-10-13 17:53 ` [igt-dev] ✓ Fi.CI.BAT: success for Fix kms_psr2_sf test and add new test for FB_DAMAGE_CLIPS plane property (rev2) Patchwork
2021-10-13 18:59 ` [igt-dev] ✓ Fi.CI.IGT: " Patchwork

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20211013171051.26287-2-jeevan.b@intel.com \
    --to=jeevan.b@intel.com \
    --cc=daniel@ffwll.ch \
    --cc=igt-dev@lists.freedesktop.org \
    --cc=jose.souza@intel.com \
    --cc=petri.latvala@intel.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox